@@ -13,7 +13,7 @@ import pytest
 from tests.coveragetest import CoverageTest, TESTS_DIR
 from tests.goldtest import compare, gold_path
 from tests.goldtest import contains, contains_any, contains_rx, doesnt_contain
-from tests.helpers import re_line, remove_tree
+from tests.helpers import os_sep, re_line, remove_tree
 
 GOOD_GETTY = """\
 Four score and seven years ago our fathers brought forth upon this continent, a
@@ -47,6 +47,7 @@ GOLD_GETTY_FILE_RX = path_regex(GOLD_GETTY_FILE)
 GOLD_PATH_RX = path_regex("/tests/gold/testing/getty/gettysburg.txt")
 OUT_PATH_RX = path_regex("out/gettysburg.txt")
 
+@pytest.mark.xdist_group(name="compare_test")
 class CompareTest(CoverageTest):
     """Tests of goldtest.py:compare()"""
 
@@ -63,7 +64,7 @@ class CompareTest(CoverageTest):
         self.make_file("out/gettysburg.txt", BAD_GETTY)
 
         # compare() raises an assertion.
-        msg = rf"Files differ: .*{GOLD_PATH_RX} != {OUT_PATH_RX}"
+        msg = fr"Files differ: .*{GOLD_PATH_RX} != {OUT_PATH_RX}"
         with pytest.raises(AssertionError, match=msg):
             compare(gold_path("testing/getty"), "out", scrubs=SCRUBS)
 
@@ -71,12 +72,16 @@ class CompareTest(CoverageTest):
         stdout = self.stdout()
         assert "- Four score" in stdout
         assert "+ Five score" in stdout
-        assert re_line(rf"^:::: diff '.*{GOLD_PATH_RX}' and '{OUT_PATH_RX}'", stdout)
-        assert re_line(rf"^:::: end diff '.*{GOLD_PATH_RX}' and '{OUT_PATH_RX}'", stdout)
+        assert re_line(fr"^:::: diff '.*{GOLD_PATH_RX}' and '{OUT_PATH_RX}'", stdout)
+        assert re_line(fr"^:::: end diff '.*{GOLD_PATH_RX}' and '{OUT_PATH_RX}'", stdout)
+        assert (
+            os_sep(f"Saved actual output to '{ACTUAL_GETTY_FILE}': see tests/gold/README.rst")
+            in os_sep(stdout)
+        )
         assert "  D/D/D, Gxxx, Pennsylvania" in stdout
 
         # The actual file was saved.
-        with open(ACTUAL_GETTY_FILE) as f:
+        with open(ACTUAL_GETTY_FILE, encoding="utf-8") as f:
             saved = f.read()
         assert saved == BAD_GETTY
 
@@ -85,7 +90,7 @@ class CompareTest(CoverageTest):
         self.make_file("out/gettysburg.txt", GOOD_GETTY)
 
         # compare() raises an assertion.
-        msg = rf"Files differ: .*{GOLD_PATH_RX} != {OUT_PATH_RX}"
+        msg = fr"Files differ: .*{GOLD_PATH_RX} != {OUT_PATH_RX}"
         with pytest.raises(AssertionError, match=msg):
             compare(gold_path("testing/getty"), "out")
 
@@ -101,7 +106,8 @@ class CompareTest(CoverageTest):
         compare(gold_path("testing/getty"), "out", scrubs=SCRUBS, actual_extra=True)
 
         # But not without it:
-        msg = r"Files in out only: \['another.more'\]"
+        # (test output is in files like /tmp/pytest-of-user/pytest-0/popen-gw3/t76/out)
+        msg = r"Files in .*[/\\]t\d+[/\\]out only: \['another.more'\]"
         with pytest.raises(AssertionError, match=msg):
             compare(gold_path("testing/getty"), "out", scrubs=SCRUBS)
         self.assert_exists(os.path.join(TESTS_DIR, "actual/testing/getty/another.more"))
@@ -133,7 +139,7 @@ class CompareTest(CoverageTest):
         # compare() raises an exception.
         gold_rx = path_regex(gold_path("testing/xml/output.xml"))
         out_rx = path_regex("out/output.xml")
-        msg = rf"Files differ: .*{gold_rx} != {out_rx}"
+        msg = fr"Files differ: .*{gold_rx} != {out_rx}"
         with pytest.raises(AssertionError, match=msg):
             compare(gold_path("testing/xml"), "out", scrubs=SCRUBS)
 
@@ -151,24 +157,24 @@ class ContainsTest(CoverageTest):
 
     def test_contains(self) -> None:
         contains(GOLD_GETTY_FILE, "Four", "fathers", "dedicated")
-        msg = rf"Missing content in {GOLD_GETTY_FILE_RX}: 'xyzzy'"
+        msg = fr"Missing content in {GOLD_GETTY_FILE_RX}: 'xyzzy'"
         with pytest.raises(AssertionError, match=msg):
             contains(GOLD_GETTY_FILE, "Four", "fathers", "xyzzy", "dedicated")
 
     def test_contains_rx(self) -> None:
         contains_rx(GOLD_GETTY_FILE, r"Fo.r", r"f[abc]thers", "dedi[cdef]ated")
-        msg = rf"Missing regex in {GOLD_GETTY_FILE_RX}: r'm\[opq\]thers'"
+        msg = fr"Missing regex in {GOLD_GETTY_FILE_RX}: r'm\[opq\]thers'"
         with pytest.raises(AssertionError, match=msg):
             contains_rx(GOLD_GETTY_FILE, r"Fo.r", r"m[opq]thers")
 
     def test_contains_any(self) -> None:
         contains_any(GOLD_GETTY_FILE, "Five", "Four", "Three")
-        msg = rf"Missing content in {GOLD_GETTY_FILE_RX}: 'One' \[1 of 3\]"
+        msg = fr"Missing content in {GOLD_GETTY_FILE_RX}: 'One' \[1 of 3\]"
         with pytest.raises(AssertionError, match=msg):
             contains_any(GOLD_GETTY_FILE, "One", "Two", "Three")
 
     def test_doesnt_contain(self) -> None:
         doesnt_contain(GOLD_GETTY_FILE, "One", "Two", "Three")
-        msg = rf"Forbidden content in {GOLD_GETTY_FILE_RX}: 'Four'"
+        msg = fr"Forbidden content in {GOLD_GETTY_FILE_RX}: 'Four'"
         with pytest.raises(AssertionError, match=msg):
             doesnt_contain(GOLD_GETTY_FILE, "Three", "Four", "Five")
